@@ -11,12 +11,21 @@ class BaseField(object):
 
     _types = None
 
-    def __init__(self, required=False, data_transformer=None, help_text=None):
+    def __init__(
+            self,
+            required=False,
+            data_transformer=None,
+            help_text=None,
+            validators=None):
         """Init."""
         self.required = required
         self.data_transformer = data_transformer
         self.help_text = help_text
 
+        if validators and not isinstance(validators, list):
+            validators = list((validators,))
+        self.validators = validators
+
     @property
     def types(self):
         """Get types."""
@@ -39,6 +48,8 @@ class BaseField(object):
         if value is None and self.required:
             raise ValidationError('Field "{}" is required!'.format(name))
 
+        self._validate_with_custom_validators(value)
+
     def to_struct(self, value):
         """Cast value to Python structure."""
         return value
@@ -50,6 +61,14 @@ class BaseField(object):
         else:
             return value
 
+    def _validate_with_custom_validators(self, value):
+        if self.validators:
+            for validator in self.validators:
+                try:
+                    validator.validate(value)
+                except AttributeError:
+                    validator(value)
+
     @staticmethod
     def get_value_replacement():
         """Get replacement for field."""
